@@ -26,17 +26,12 @@
 #include "common/utils.hh"
 #include "sum.hh"
 
-#if defined(PTL_USE_TIMEMORY)
-#    include "timemory/auto_timer.hpp"
-#    include "timemory/manager.hpp"
-#endif
-
 //============================================================================//
 
 ThreadPool*&
 GetGpuPool()
 {
-    ThreadLocalStatic ThreadPool* _instance = nullptr;
+    static thread_local ThreadPool* _instance = nullptr;
     return _instance;
 }
 
@@ -45,7 +40,7 @@ GetGpuPool()
 TaskManager*&
 GetGpuManager()
 {
-    ThreadLocalStatic TaskManager* _instance = nullptr;
+    static thread_local TaskManager* _instance = nullptr;
     return _instance;
 }
 
@@ -126,16 +121,10 @@ execute_gpu_iterations(uint64_t num_iter, TaskGroup_t* task_group, uint64_t n)
 //============================================================================//
 
 int
-main(int argc, char** argv)
+main()
 {
     _pause_collection;  // for VTune
 
-#if defined(PTL_USE_TIMEMORY)
-    tim::manager* manager = tim::manager::instance();
-#endif
-
-    ConsumeParameters(argc, argv);
-
     auto hwthreads        = std::thread::hardware_concurrency();
     auto default_fib      = 42;
     auto default_tg       = 2;
@@ -158,9 +147,8 @@ main(int argc, char** argv)
                                      "Setting the centerpoint of fib work distribution");
     uint64_t ngpu =
         GetEnv<uint64_t>("GPU_RANGE", default_gpu, "Setting the GPU range centerpoint");
-    uint64_t grainsize =
-        GetEnv<uint64_t>("GRAINSIZE", numThreads,
-                         "Dividing number of task into grain of this size");
+    uint64_t grainsize = GetEnv<uint64_t>(
+        "GRAINSIZE", numThreads, "Dividing number of task into grain of this size");
     uint64_t num_iter = GetEnv<uint64_t>("NUM_TASKS", numThreads * numThreads,
                                          "Setting the number of total tasks");
     uint64_t num_groups =
@@ -200,8 +188,8 @@ main(int argc, char** argv)
     //                                                                        //
     //------------------------------------------------------------------------//
     {
-        fuint64_t fib_async = taskManager->async<uint64_t>(fibonacci, nfib);
-        uint64_t  fib_n     = fib_async.get();
+        auto     fib_async = taskManager->async<uint64_t>(fibonacci, nfib);
+        uint64_t fib_n     = fib_async->get();
         std::cout << prefix << "[async test] fibonacci(" << nfib << " +/- " << rng_range
                   << ") = " << fib_n << std::endl;
         std::cout << std::endl;
@@ -406,13 +394,6 @@ main(int argc, char** argv)
 
     delete runManager;
 
-#if defined(PTL_USE_TIMEMORY)
-    std::string fname(argv[0]);
-    manager->report(std::cout, true);
-    manager->write_report(fname + ".out");
-    manager->write_json(fname + ".json");
-#endif
-
     return static_cast<int>(ret);
 }
 
